@@ -56,6 +56,7 @@ class DBMonitorProvider(object):
         
         LOG.info('Creating monitoring on DBMonitor')
         environment = databaseinfra.environment
+        sgbd = self.get_sgbd(databaseinfra)
         instances = databaseinfra.instances.all()
         if len(instances) == 1:
             flag_cluster_str = 'false'
@@ -65,8 +66,16 @@ class DBMonitorProvider(object):
             flag_cluster_str = 'true'
             flag_cluster = True
             machine = ''
-        sgbd = self.get_sgbd(databaseinfra)
-        dns, port = databaseinfra.endpoint_dns.split(':')
+        
+        if sgbd == SGBD_MYSQL:
+            dns, port = databaseinfra.endpoint_dns.split(':')
+            replicasetname = ''
+        else:
+            dns, port = databaseinfra.get_driver().get_dns_port()
+            replicasetname = databaseinfra.get_driver().get_replica_name()
+            if replicasetname is None:
+                replicasetname = ''
+
         self.auth(environment)
         
         tipo = EnvironmentAttr.objects.get(dbaas_environment=environment).dbmonitor_environment
@@ -74,13 +83,13 @@ class DBMonitorProvider(object):
         sql = """INSERT INTO dbmonitor_database ( nome, maquina, sgbd, tipo, dns, porta, versao, usuario, senha,
                              ativo, flag_cluster, coleta_info_sessoes, coleta_info_tablespaces, coleta_info_segmentos,
                              coleta_info_backup, coleta_info_key_buffer, testa_conexao, coleta_tamanho_database,
-                             flag_autenticacao, testa_replicacao )
+                             flag_autenticacao, testa_replicacao, replicaset )
                  VALUES (
                  '%(nome)s', '%(maquina)s', '%(sgbd)s', '%(tipo)s', '%(dns)s', '%(porta)s', '%(versao)s', '%(usuario)s', 
                  encode('%(senha)s', '%(decodekey)s'), 
                  %(ativo)s, %(flag_cluster)s, %(coleta_info_sessoes)s, %(coleta_info_tablespaces)s, %(coleta_info_segmentos)s,
                  %(coleta_info_backup)s, %(coleta_info_key_buffer)s, %(testa_conexao)s, %(coleta_tamanho_database)s,
-                 %(flag_autenticacao)s, %(testa_replicacao)s
+                 %(flag_autenticacao)s, %(testa_replicacao)s, '%(replicaset)s'
                  )
         """ % {
         'nome': databaseinfra.name[:50],
@@ -102,8 +111,9 @@ class DBMonitorProvider(object):
         'coleta_info_key_buffer': 'false',
         'testa_conexao': 'true',
         'coleta_tamanho_database': 'true',
-        'flag_autenticacao': 'false',
-        'testa_replicacao': 'false',
+        'flag_autenticacao': 'true',
+        'testa_replicacao': 'true',
+        'replicaset':replicasetname
         }
         
         try:
@@ -115,16 +125,32 @@ class DBMonitorProvider(object):
                 cont = 0
                 for instance in instances:
                     cont+=1
-                    sql2 = """INSERT INTO dbmonitor_instancia (database_id, nome, maquina, dns, porta, ativo)
-                              VALUES (%(database_id)s, '%(nome)s', '%(maquina)s', '%(dns)s', '%(porta)s', %(ativo)s)
-                    """ % {
+                    instance_dict = {
                     'database_id': dbmonitor_infraid,
                     'nome': databaseinfra.name[:48]+ '-' + str(cont),
                     'maquina': instance.hostname,
                     'dns': instance.dns,
                     'porta': instance.port,
                     'ativo': 'true',
+                    'tipo_mongodb': '',
                     }
+                    
+                    if sgbd == SGBD_MONGODB:
+                        if cont == 1:
+                            instance_dict['tipo_mongodb'] = '1'
+                        elif cont == 2:
+                            instance_dict['tipo_mongodb'] = '2'
+                        else:
+                            instance_dict['tipo_mongodb'] = '7'
+                            
+                        sql2 = """INSERT INTO dbmonitor_instancia (database_id, nome, maquina, dns, porta, ativo, tipo_mongodb)
+                                VALUES (%(database_id)s, '%(nome)s', '%(maquina)s', '%(dns)s', '%(porta)s', %(ativo)s, '%(tipo_mongodb)s')
+                        """ % instance_dict
+                    else:
+                        sql2 = """INSERT INTO dbmonitor_instancia (database_id, nome, maquina, dns, porta, ativo)
+                                VALUES (%(database_id)s, '%(nome)s', '%(maquina)s', '%(dns)s', '%(porta)s', %(ativo)s)
+                        """ % instance_dict
+                         
                     cursor.execute(sql2)
             self.client.commit()
             dbinfraattr = DatabaseInfraAttr(dbaas_databaseinfra = databaseinfra, dbmonitor_databaseinfra = dbmonitor_infraid)
